@@ -86,6 +86,7 @@ BREAK_IF(){
 			if [ "$NOW_DIR" = "admin" ]; then
 				echo "$NOW_DIR"
 				cat ../apps/*.if >> $ALL_EXCLUDE_MYSELF_CURRENT
+				cat ../contrib/*.if >> $ALL_EXCLUDE_MYSELF_CURRENT
 				cat ../kernel/*.if >> $ALL_EXCLUDE_MYSELF_CURRENT
 				cat ../roles/*.if >> $ALL_EXCLUDE_MYSELF_CURRENT
 				cat ../services/*.if >> $ALL_EXCLUDE_MYSELF_CURRENT
@@ -94,6 +95,16 @@ BREAK_IF(){
 			if [ "$NOW_DIR" = "apps" ]; then
 				echo "$NOW_DIR"
 				cat ../admin/*.if >> $ALL_EXCLUDE_MYSELF_CURRENT
+				cat ../contrib/*.if >> $ALL_EXCLUDE_MYSELF_CURRENT
+				cat ../kernel/*.if >> $ALL_EXCLUDE_MYSELF_CURRENT
+				cat ../roles/*.if >> $ALL_EXCLUDE_MYSELF_CURRENT
+				cat ../services/*.if >> $ALL_EXCLUDE_MYSELF_CURRENT
+				cat ../system/*.if >> $ALL_EXCLUDE_MYSELF_CURRENT
+			fi
+			if [ "$NOW_DIR" = "contrib" ]; then
+				echo "$NOW_DIR"
+				cat ../admin/*.if >> $ALL_EXCLUDE_MYSELF_CURRENT
+				cat ../apps/*.if >> $ALL_EXCLUDE_MYSELF_CURRENT
 				cat ../kernel/*.if >> $ALL_EXCLUDE_MYSELF_CURRENT
 				cat ../roles/*.if >> $ALL_EXCLUDE_MYSELF_CURRENT
 				cat ../services/*.if >> $ALL_EXCLUDE_MYSELF_CURRENT
@@ -103,6 +114,7 @@ BREAK_IF(){
 				echo "$NOW_DIR"
 				cat ../admin/*.if >> $ALL_EXCLUDE_MYSELF_CURRENT
 				cat ../apps/*.if >> $ALL_EXCLUDE_MYSELF_CURRENT
+				cat ../contrib/*.if >> $ALL_EXCLUDE_MYSELF_CURRENT
 				cat ../roles/*.if >> $ALL_EXCLUDE_MYSELF_CURRENT
 				cat ../services/*.if >> $ALL_EXCLUDE_MYSELF_CURRENT
 				cat ../system/*.if >> $ALL_EXCLUDE_MYSELF_CURRENT
@@ -111,6 +123,7 @@ BREAK_IF(){
 				echo "$NOW_DIR"
 				cat ../admin/*.if >> $ALL_EXCLUDE_MYSELF_CURRENT
 				cat ../apps/*.if >> $ALL_EXCLUDE_MYSELF_CURRENT
+				cat ../contrib/*.if >> $ALL_EXCLUDE_MYSELF_CURRENT
 				cat ../kernel/*.if >> $ALL_EXCLUDE_MYSELF_CURRENT
 				cat ../services/*.if >> $ALL_EXCLUDE_MYSELF_CURRENT
 				cat ../system/*.if >> $ALL_EXCLUDE_MYSELF_CURRENT
@@ -119,6 +132,7 @@ BREAK_IF(){
 				echo "$NOW_DIR"
 				cat ../admin/*.if >> $ALL_EXCLUDE_MYSELF_CURRENT
 				cat ../apps/*.if >> $ALL_EXCLUDE_MYSELF_CURRENT
+				cat ../contrib/*.if >> $ALL_EXCLUDE_MYSELF_CURRENT
 				cat ../kernel/*.if >> $ALL_EXCLUDE_MYSELF_CURRENT
 				cat ../roles/*.if >> $ALL_EXCLUDE_MYSELF_CURRENT
 				cat ../system/*.if >> $ALL_EXCLUDE_MYSELF_CURRENT
@@ -127,6 +141,7 @@ BREAK_IF(){
 				echo "$NOW_DIR"
 				cat ../admin/*.if >> $ALL_EXCLUDE_MYSELF_CURRENT
 				cat ../apps/*.if >> $ALL_EXCLUDE_MYSELF_CURRENT
+				cat ../contrib/*.if >> $ALL_EXCLUDE_MYSELF_CURRENT
 				cat ../kernel/*.if >> $ALL_EXCLUDE_MYSELF_CURRENT
 				cat ../roles/*.if >> $ALL_EXCLUDE_MYSELF_CURRENT
 				cat ../services/*.if >> $ALL_EXCLUDE_MYSELF_CURRENT
@@ -202,6 +217,6 @@ do
 	)
 done
 
-echo "Breaking script Successfully finished."
+echo "Breaking .if scripts Successfully finished."
 
 exit $ERROR
